@@ -15,16 +15,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-version = '0.1.27'
+version = '0.1.28'
 release = 'barium'
 
 import os
 import sys
+import traceback
 from datetime import datetime
 
 from lettuce import fs
 
-from lettuce.core import Feature, TotalResult
+from lettuce.core import Feature, TotalResult, RunController
 
 from lettuce.terrain import after
 from lettuce.terrain import before
@@ -61,7 +62,8 @@ class Runner(object):
     features and step definitions on there.
     """
     def __init__(self, base_path, scenarios=None, verbosity=0,
-                 enable_xunit=False, xunit_filename=None):
+                 enable_xunit=False, xunit_filename=None,
+                 run_controller=None):
         """ lettuce.Runner will try to find a terrain.py file and
         import it from within `base_path`
         """
@@ -74,6 +76,7 @@ class Runner(object):
         sys.path.insert(0, base_path)
         self.loader = fs.FeatureLoader(base_path)
         self.verbosity = verbosity
+        self.run_controller = run_controller or RunController()
         self.scenarios = scenarios and map(int, scenarios.split(",")) or None
 
         sys.path.remove(base_path)
@@ -123,10 +126,15 @@ class Runner(object):
         try:
             for filename in features_files:
                 feature = Feature.from_file(filename)
-                results.append(feature.run(self.scenarios))
+                results.append(feature.run(self.scenarios, self.run_controller))
         except exceptions.LettuceSyntaxError, e:
             sys.stderr.write(e.msg)
             failed = True
+        except:
+            e = sys.exc_info()[1]
+            print "Died with "+str(e)
+            traceback.print_exc()
+            failed = True
 
         finally:
             if failed:
