@@ -32,13 +32,20 @@ from django.core.servers.basehttp import ServerHandler
 from django.core.servers.basehttp import WSGIRequestHandler
 from django.core.servers.basehttp import WSGIServerException
 from django.core.servers.basehttp import AdminMediaHandler
+try:
+    from django.contrib.staticfiles.handlers import StaticFilesHandler
+except ImportError:
+    StaticFilesHandler = None
 
 from lettuce.registry import call_hook
 
+
 class LettuceServerException(WSGIServerException):
     pass
 
 keep_running = True
+
+
 class StopabbleHandler(object):
     """WSGI middleware that intercepts HTTP method DELETE at / and
     kills through StopIteration exception server"""
@@ -47,35 +54,39 @@ class StopabbleHandler(object):
         self.application = application
 
     def __call__(self, environ, start_response):
-        if environ['PATH_INFO'] == '/' and environ['REQUEST_METHOD'] == 'DELETE':
+        if environ['PATH_INFO'] == '/' and \
+               environ['REQUEST_METHOD'] == 'DELETE':
             global keep_running
             keep_running = False
 
         return self.application(environ, start_response)
 
+
 class MutedRequestHandler(WSGIRequestHandler):
     """ A RequestHandler that silences output, in order to don't
     mess with Lettuce's output"""
 
     dev_null = StringIO()
+
     def log_message(self, *args, **kw):
-        pass # do nothing
+        pass  # do nothing
 
     def handle(self):
         """Handle a single HTTP request"""
         self.raw_requestline = self.rfile.readline()
-        if not self.parse_request(): # An error code has been sent, just exit
+        if not self.parse_request():  # An error code has been sent, just exit
             return
 
         handler = LettuceServerHandler(
             self.rfile,
             self.wfile,
             self.dev_null,
-            self.get_environ()
+            self.get_environ(),
         )
         handler.request_handler = self      # backpointer for logging
         handler.run(self.server.get_app())
 
+
 class LettuceServerHandler(ServerHandler):
     def finish_response(self):
         try:
@@ -85,9 +96,11 @@ class LettuceServerHandler(ServerHandler):
         # http://code.djangoproject.com/ticket/4444
         except Exception:
             exc_type, exc_value = sys.exc_info()[:2]
-            if not issubclass(exc_type, socket.error) or exc_value.args[0] is 32:
+            if not issubclass(exc_type, socket.error) or \
+                   exc_value.args[0] is 32:
                 raise
 
+
 class ThreadedServer(threading.Thread):
     """
     Runs django's builtin in background
@@ -121,6 +134,13 @@ class ThreadedServer(threading.Thread):
 
         self.lock.acquire()
 
+    def should_serve_static_files(self):
+        conditions = [
+            StaticFilesHandler is not None,
+            getattr(settings, 'STATIC_URL', False),
+        ]
+        return all(conditions)
+
     def run(self):
         self.lock.acquire()
         pidfile = os.path.join(tempfile.gettempdir(), 'lettuce-django.pid')
@@ -161,16 +181,18 @@ class ThreadedServer(threading.Thread):
         if not bound:
             raise LettuceServerException(
                 "the port %d already being used, could not start " \
-                "django's builtin server on it" % self.port
+                "django's builtin server on it" % self.port,
             )
 
-
         handler = StopabbleHandler(WSGIHandler())
         if 'django.contrib.admin' in settings.INSTALLED_APPS:
             admin_media_path = ''
             handler = AdminMediaHandler(handler, admin_media_path)
             print "Preparing to serve django's admin site static files..."
 
+        if self.should_serve_static_files():
+            handler = StaticFilesHandler(handler)
+
         httpd.set_app(handler)
 
         global keep_running
@@ -181,6 +203,7 @@ class ThreadedServer(threading.Thread):
             if self.lock.locked():
                 self.lock.release()
 
+
 class Server(object):
     """A silenced, lightweight and simple django's builtin server so
     that lettuce can be used with selenium, webdriver, windmill or any
